==> forms-v5.2.1.tar.gz: forms/l10n/es_AR.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularios",
    "Timestamp of data load" : "Marca de tiempo de carga de datos",
    "Yes" : "Sí",
    "Copy" : "Copiar",
    "Anonymous response" : "Respuesta anónima",
    "Shared by %s" : "Compartido por %s ",
    "An error occurred while loading the forms list" : "Ocurrió un error mientras se cargaba la lista de formularios",
    "Form not found" : "Formulario no encontrado",
    "Unable to create a new form" : "No es posible crear un nuevo formulario",
    "New form" : "Nuevo formulario",
    "Shared with you" : "Compartido con usted",
    "Loading forms …" : "Cargando formulario ...",
    "No forms created yet" : "Aún no se han creado formularios",
    "Create a form" : "Crear un formulario",
    "Select a form or create a new one" : "Seleccionar un formulario o crear uno nuevo",
    "Create new form" : "Crear nuevo formulario",
    "This form does not exist" : "Este formulario no existe",
    "Form expired" : "El formulario ha expirado",
    "This form has expired and is no longer taking answers" : "Este formulario ha expirado y ya no recibe respuestas",
    "Select groups" : "Seleccionar grupos",
    "Delete form" : "Borrar formulario",
    "Error while deleting {title}" : "Error mientras se borraba {título}",
    "Are you sure you want to delete {title}?" : "Esta seguro que desea borrar {título}?",
    "Cancel" : "Cancel",
    "Options" : "Opciones",
    "Answer number {index}" : "Respuesta numero {índice}",
    "Error while saving the answer" : "Error mientras se guardaba la respuesta",
    "Delete answer" : "Borrar respuesta",
    "Question number {index}" : "Pregunta numero {índice}",
    "Title of question number {index}" : "Titulo de la pregunta numero {índice}",
    "Required" : "Requerido",
    "Delete question" : "Borrar pregunta",
    "Delete" : "Eliminar",
    "Uploading …" : "Actualizando...",
    "A long answer for the question “{text}”" : "Una respuesta larga para la pregunta \"{texto}\"",
    "A short answer for the question “{text}”" : "Una respuesta corta para la pregunta \"{texto}\"",
    "Delete this response" : "Borrar esta respuesta",
    "Expired on {date}" : "Expirado el {día}",
    "Expires on {date}" : "Expira el {día}",
    "never" : "nunca",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Group" : "Grupo",
    "Permissions" : "Permisos",
    "Share link" : "Compartir enlace",
    "Copy to clipboard" : "Copiar al portapapeles",
    "View" : "Ver",
    "Edit" : "Editar",
    "View mode" : "Modo de vista",
    "Share" : "Compartir",
    "There was an error while adding the new question" : "Hubo un error mientras se agregaba la nueva pregunta",
    "There was an error while removing the question" : "Hubo un error mientras se eliminaba la pregunta",
    "Error while saving form" : "Error mientras se guardaba el formulario",
    "Loading {title} …" : "Cargando {título}",
    "Form title" : "Título del formulario",
    "Description" : "Descripción",
    "Add a question" : "Agregar una pregunta",
    "Summary" : "Resumen",
    "Responses" : "Respuestas",
    "There was an error while removing this response" : "Hubo un error mientras se eliminaba esta respuesta",
    "There was an error while removing responses" : "Hubo un error mientras se eliminaban las respuestas",
    "Download" : "Descargar",
    "Delete all responses" : "Borrar todas las respuestas",
    "Search" : "Buscar",
    "Loading responses …" : "Cargando respuestas",
    "No responses yet" : "Aún no han habido respuestas",
    "Results of submitted forms will show up here" : "Los resultados de los formularios cargados se mostraran aquí",
    "Are you sure you want to delete all responses of {title}?" : "Estas seguro que deseas borrar todas las respuestas para {título}?",
    "Sharing" : "Compartiendo",
    "Settings" : "Ajustes",
    "Abort" : "Abortar",
    "Submit" : "Enviar",
    "Clear" : "Borrar",
    "There was an error submitting the form" : "Hubo un error al enviar el formulario",
    "Submit form" : "Enviar formulario",
    "Submitting form …" : "Enviando formulario ...",
    "Thank you for completing the form!" : "Gracias por completar el formulario!",
    "Error while saving question" : "Hubo un error mientras se guardaba la pregunta",
    "There was an issue deleting this option" : "Hubo un error mientras se eliminaba esta opción",
    "Form link copied" : "Enlace del formulario copiado",
    "Cannot copy, please copy the link manually" : "No es posible copiar, por favor copia el enlace manualmente",
    "No recommendations. Start typing." : "No hay sugerencias. Comenzar a escribir",
    "No elements found." : "No se encontraron elementos",
    "Checkboxes" : "Casillas de verificación",
    "File" : "Archivo",
    "Short answer" : "Respuesta breve",
    "Long text" : "Texto largo",
    "Date" : "Fecha",
    "Time" : "Hora",
    "Color" : "Color",
    "Text" : "Texto",
    "Phone number" : "Número telefónico"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> forms-v5.2.3.tar.gz: forms/l10n/es_AR.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularios",
    "Timestamp of data load" : "Marca de tiempo de carga de datos",
    "Yes" : "Sí",
    "Copy" : "Copiar",
    "Anonymous response" : "Respuesta anónima",
    "Shared by %s" : "Compartido por %s ",
    "An error occurred while loading the forms list" : "Ocurrió un error mientras se cargaba la lista de formularios",
    "Form not found" : "Formulario no encontrado",
    "Unable to create a new form" : "No es posible crear un nuevo formulario",
    "New form" : "Nuevo formulario",
    "Shared with you" : "Compartido con usted",
    "No forms created yet" : "Aún no se han creado formularios",
    "Create a form" : "Crear un formulario",
    "Select a form or create a new one" : "Seleccionar un formulario o crear uno nuevo",
    "Create new form" : "Crear nuevo formulario",
    "This form does not exist" : "Este formulario no existe",
    "Form expired" : "El formulario ha expirado",
    "This form has expired and is no longer taking answers" : "Este formulario ha expirado y ya no recibe respuestas",
    "Select groups" : "Seleccionar grupos",
    "Delete form" : "Borrar formulario",
    "Error while deleting {title}" : "Error mientras se borraba {título}",
    "Are you sure you want to delete {title}?" : "Esta seguro que desea borrar {título}?",
    "Cancel" : "Cancel",
    "Options" : "Opciones",
    "Answer number {index}" : "Respuesta numero {índice}",
    "Error while saving the answer" : "Error mientras se guardaba la respuesta",
    "Delete answer" : "Borrar respuesta",
    "Question number {index}" : "Pregunta numero {índice}",
    "Title of question number {index}" : "Titulo de la pregunta numero {índice}",
    "Required" : "Requerido",
    "Delete question" : "Borrar pregunta",
    "Delete" : "Eliminar",
    "A long answer for the question “{text}”" : "Una respuesta larga para la pregunta \"{texto}\"",
    "A short answer for the question “{text}”" : "Una respuesta corta para la pregunta \"{texto}\"",
    "Delete this response" : "Borrar esta respuesta",
    "Expired on {date}" : "Expirado el {día}",
    "Expires on {date}" : "Expira el {día}",
    "never" : "nunca",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Group" : "Grupo",
    "Permissions" : "Permisos",
    "Share link" : "Compartir enlace",
    "Copy to clipboard" : "Copiar al portapapeles",
    "View" : "Ver",
    "Edit" : "Editar",
    "View mode" : "Modo de vista",
    "Share" : "Compartir",
    "There was an error while adding the new question" : "Hubo un error mientras se agregaba la nueva pregunta",
    "There was an error while removing the question" : "Hubo un error mientras se eliminaba la pregunta",
    "Error while saving form" : "Error mientras se guardaba el formulario",
    "Form title" : "Título del formulario",
    "Description" : "Descripción",
    "Add a question" : "Agregar una pregunta",
    "Summary" : "Resumen",
    "Responses" : "Respuestas",
    "There was an error while removing this response" : "Hubo un error mientras se eliminaba esta respuesta",
    "There was an error while removing responses" : "Hubo un error mientras se eliminaban las respuestas",
    "Download" : "Descargar",
    "Delete all responses" : "Borrar todas las respuestas",
    "Search" : "Buscar",
    "No responses yet" : "Aún no han habido respuestas",
    "Results of submitted forms will show up here" : "Los resultados de los formularios cargados se mostraran aquí",
    "Are you sure you want to delete all responses of {title}?" : "Estas seguro que deseas borrar todas las respuestas para {título}?",
    "Sharing" : "Compartiendo",
    "Settings" : "Ajustes",
    "Abort" : "Abortar",
    "Submit" : "Enviar",
    "Clear" : "Borrar",
    "There was an error submitting the form" : "Hubo un error al enviar el formulario",
    "Submit form" : "Enviar formulario",
    "Thank you for completing the form!" : "Gracias por completar el formulario!",
    "Error while saving question" : "Hubo un error mientras se guardaba la pregunta",
    "There was an issue deleting this option" : "Hubo un error mientras se eliminaba esta opción",
    "Form link copied" : "Enlace del formulario copiado",
    "Cannot copy, please copy the link manually" : "No es posible copiar, por favor copia el enlace manualmente",
    "No recommendations. Start typing." : "No hay sugerencias. Comenzar a escribir",
    "No elements found." : "No se encontraron elementos",
    "Checkboxes" : "Casillas de verificación",
    "File" : "Archivo",
    "Short answer" : "Respuesta breve",
    "Long text" : "Texto largo",
    "Date" : "Fecha",
    "Time" : "Hora",
    "Color" : "Color",
    "Text" : "Texto",
    "Phone number" : "Número telefónico",
    "Loading forms …" : "Cargando formulario ...",
    "Uploading …" : "Actualizando...",
    "Loading {title} …" : "Cargando {título}",
    "Loading responses …" : "Cargando respuestas",
    "Submitting form …" : "Enviando formulario ..."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
